==> quarks_1.1.1.tar.gz: quarks/NEWS.md <==
# quarks 1.1.1

- slightly adjusted print method for 'cvgtest.R'

# quarks 1.1.0

- implemented 4 new functions which enable the user to apply various
  backtesting methods
  
# quarks 1.0.11

- slightly adjusted plot method (added a grid)
- updated data sets
- changed name of 'DAX30' to 'DAX' due to the recent extension of
  the German Stock Market Index
  
# quarks 1.0.10

- added a print method for 'quarks'

# quarks 1.0.9

- fixed a bug in 'hs.R'

# quarks 1.0.8

- fixed a bug which caused an error in 'vwhs.R' and 'fhs.R'

# quarks 1.0.7

- changed output value of 'hs.R', 'vwhs.R' and 'fhs.R'
- modified 'plot.quarks.R'; main title and axis labels can now be adjusted
  manually
- added five financial time series data sets

# quarks 1.0.6

- changed default of coverage level (p) from 0.95 to 0.975
- implemented 'fhs.R', enabling filtered historical simulation
- implemented volatility estimation with GARCH-type models by means of the
  'rugarch' package


# quarks 1.0.5

- slightly changed example for 'rollcast.R'
- fixed a bug which caused a warning if argument 'method'
  in 'rollcast.R' was set on default

# quarks 1.0.4

- slightly adapted 'hs.R', 'vwhs.R' and 'rollcast.R' 
- modified ES-calculation for age-weighted historical simulation

# quarks 1.0.3

- slightly adjusted README
- modified 'plot.quarks.R'

# quarks 1.0.2

- fixed a minor bug in 'hs.R'
- minor adjustments in the README were made

# quarks 1.0.1

- adjusted example in the README file
- minor adjustments in the documentation were made

==> quarks_1.1.2.tar.gz: quarks/NEWS.md <==
# quarks 1.1.2

- added argument 'conflvl' to 'cvgtest.R' in order to set the significance 
  level for hypothesis testing

# quarks 1.1.1

- slightly adjusted print method for 'cvgtest.R'

# quarks 1.1.0

- implemented 4 new functions which enable the user to apply various
  backtesting methods
  
# quarks 1.0.11

- slightly adjusted plot method (added a grid)
- updated data sets
- changed name of 'DAX30' to 'DAX' due to the recent extension of
  the German Stock Market Index
  
# quarks 1.0.10

- added a print method for 'quarks'

# quarks 1.0.9

- fixed a bug in 'hs.R'

# quarks 1.0.8

- fixed a bug which caused an error in 'vwhs.R' and 'fhs.R'

# quarks 1.0.7

- changed output value of 'hs.R', 'vwhs.R' and 'fhs.R'
- modified 'plot.quarks.R'; main title and axis labels can now be adjusted
  manually
- added five financial time series data sets

# quarks 1.0.6

- changed default of coverage level (p) from 0.95 to 0.975
- implemented 'fhs.R', enabling filtered historical simulation
- implemented volatility estimation with GARCH-type models by means of the
  'rugarch' package


# quarks 1.0.5

- slightly changed example for 'rollcast.R'
- fixed a bug which caused a warning if argument 'method'
  in 'rollcast.R' was set on default

# quarks 1.0.4

- slightly adapted 'hs.R', 'vwhs.R' and 'rollcast.R' 
- modified ES-calculation for age-weighted historical simulation

# quarks 1.0.3

- slightly adjusted README
- modified 'plot.quarks.R'

# quarks 1.0.2

- fixed a minor bug in 'hs.R'
- minor adjustments in the README were made

# quarks 1.0.1

- adjusted example in the README file
- minor adjustments in the documentation were made
